@@ -2,7 +2,7 @@
 This file defines the GUI for running Karel programs.
 
 Original Author: Nicholas Bowman
-Credits: Kylie Jue
+Credits: Kylie Jue, Tyler Yep
 License: MIT
 Version: 1.0.0
 Email: nbowman@stanford.edu
@@ -16,20 +16,21 @@ import os
 import sys
 import tkinter as tk
 import traceback as tb
-import types
 from time import sleep
 from tkinter.filedialog import askopenfilename
 from tkinter.messagebox import showwarning
 
 from stanfordkarel.karel_canvas import KarelCanvas
-from stanfordkarel.karel_definitions import *
+from stanfordkarel.karel_definitions import DEFAULT_ICON, LIGHT_GREY, PAD_X, PAD_Y, KarelException
 
 
 class StudentCode:
-    def __init__(self, code_file, karel):
-        # This process is used to extract a module from an arbitarily located
-        # file that contains student code. Adapted from:
-        # https://stackoverflow.com/questions/67631/how-to-import-a-module-given-the-full-path
+    """
+    This process extracts a module from an arbitary file that contains student code.
+    https://stackoverflow.com/questions/67631/how-to-import-a-module-given-the-full-path
+    """
+
+    def __init__(self, code_file, karel=None):
         self.module_name = os.path.splitext(os.path.basename(code_file))[0]
         spec = importlib.util.spec_from_file_location(self.module_name, os.path.abspath(code_file))
         try:
@@ -39,14 +40,15 @@ class StudentCode:
             # Handle syntax errors and only print location of error
             print(f"Syntax Error: {e}")
             print("\n".join(tb.format_exc(limit=0).split("\n")[1:]))
-            self.mod = None
+            sys.exit()
 
         # Do not proceed if the student has not defined a main function.
         if not hasattr(self.mod, "main"):
             print("Couldn't find the main() function. Are you sure you have one?")
             sys.exit()
 
-        self.inject_namespace(karel)
+        if karel:
+            self.inject_namespace(karel)
 
     def inject_namespace(self, karel):
         """
@@ -289,7 +291,7 @@ class KarelApplication(tk.Frame):
             # get the name of the file corresponding to the current frame
             filename = frame_info.filename
             # Only display frames generated within the student's code
-            if self.student_code.base_filename + ".py" in filename:
+            if self.student_code.module_name + ".py" in filename:
                 display_frames.append((frame, lineno))
 
         print(("".join(tb.format_list(tb.StackSummary.extract(display_frames)))).strip())
