@@ -32,7 +32,7 @@ World File Constraints:
 	- South
 
 Original Author: Nicholas Bowman
-Credits: Kylie Jue
+Credits: Kylie Jue, Tyler Yep
 License: MIT
 Version: 1.0.0
 Email: nbowman@stanford.edu
@@ -45,7 +45,20 @@ import os
 import re
 import sys
 
-from stanfordkarel.karel_definitions import *
+from stanfordkarel.karel_definitions import (
+    DIRECTIONS_MAP,
+    DIRECTIONS_MAP_INVERSE,
+    INFINITY,
+    Direction,
+    Wall,
+)
+
+INIT_SPEED = 50
+VALID_WORLD_KEYWORDS = ["dimension", "wall", "beeper", "karel", "speed", "beeperbag", "color"]
+VALID_DIRECTIONS = ["east", "west", "north", "south"]
+KEYWORD_DELIM = ":"
+PARAM_DELIM = ";"
+DEFAULT_WORLD_FILE = "DefaultWorld.w"
 
 
 class KarelWorld:
@@ -53,7 +66,7 @@ class KarelWorld:
         """
 		Karel World constructor
 		Parameters:
-			world_file: Open file object containing information about the initial state of Karel's world
+			world_file: filename of world file containing the initial state of Karel's world
 		"""
         self._world_file = self.process_world(world_file) if world_file else None
 
@@ -96,18 +109,26 @@ class KarelWorld:
 
     @staticmethod
     def process_world(world_file):
-        # Create the world as specified in the given world file
-        worlds_prefix = os.path.join("worlds", world_file)
-        if os.path.isfile(world_file):
-            # Attempt to open the file that has been specified
-            world_file = open(world_file)
-        elif os.path.isfile(worlds_prefix):
-            # Before failing, look inside the worlds folder for this file
+        # Find world file that matches program name in the worlds/ directory
+        worlds_prefix = os.path.join("worlds", world_file + ".w")
+        if not os.path.isdir("worlds"):
+            print("Could not find worlds/ folder. Please store worlds in a folder with this name.")
+
+        if os.path.isfile(worlds_prefix):
+            # First look inside the worlds folder for this file
             world_file = open(worlds_prefix)
+        elif os.path.isfile(world_file):
+            # Attempt to open the exact filename that has been specified
+            world_file = open(world_file)
         else:
-            # Print warning to user and exit out of the program
-            print(f"Could not find world file with name: {world_file}")
-            sys.exit()
+            default_world = os.path.join("worlds", DEFAULT_WORLD_FILE)
+            print(f"Could not find world file: {world_file}.w. Using default world instead.")
+            if os.path.isfile(default_world):
+                world_file = open(default_world)
+            else:
+                print("Could not find default world to use. Please specify a valid world filename.")
+                sys.exit()
+
         return world_file
 
     @property
